/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.implement;

import java.util.ArrayList;
import java.util.List;
import nl.cloudfarming.client.fleet.implement.tree.ImplementCategoryNodeFactory;
import nl.cloudfarming.client.fleet.model.ImplementManager;
import nl.cloudfarming.client.fleet.model.ImplementService;
import nl.cloudfarming.client.fleet.model.Machine;
import org.netbeans.api.project.Project;
import org.openide.filesystems.FileObject;
import org.openide.util.Lookup;
import org.openide.util.lookup.ServiceProvider;

/**
 *
 * @author Maciek Dulkiewicz <maciek.dulkiewicz@ordina.nl>
 * @author Wytse Visser
 */
@ServiceProvider(service = ImplementService.class)
public class ImplementServiceImpl implements ImplementService {

    @Override
    public List<Machine> getMachines(Project fleetProject) {
        List<Machine> implementList = new ArrayList<>();
        FileObject implementsDir = getImplementsDirectory(fleetProject);
        
        if(implementsDir != null) {
            FileObject[] children = implementsDir.getChildren();
            for (FileObject child : children) {
                implementList.add(loadMachine(child));
            }
        }

        return implementList;
    }

    @Override
    public Machine getMachine(Project fleetProject, String name) {
        Machine machine = null;
        FileObject implementsDir = getImplementsDirectory(fleetProject);
        if(implementsDir != null) {
            return loadMachine(implementsDir.getFileObject(name, "imt"));
        }

        return machine;
    }
    
    private static FileObject getImplementsDirectory(Project fleetProject) {
        String ImplementsDirName = ImplementCategoryNodeFactory.getDirectoryName();
        return fleetProject.getProjectDirectory().getFileObject(ImplementsDirName);
    }
    
    private static Machine loadMachine(FileObject machineFile) {
        if(machineFile == null) {
            return null;
        }
        
        Lookup lookup = Lookup.getDefault();
        ImplementManager implementManager = lookup.lookup(ImplementManager.class);
        return implementManager.load(machineFile);
    }
}
