/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.implement.tree;

import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.fleet.machine.tree.MachineCategoryChildFactory;
import org.openide.filesystems.FileObject;
import org.openide.loaders.DataObjectNotFoundException;
import org.openide.nodes.AbstractNode;
import org.openide.nodes.Children;
import org.openide.nodes.Node;

/**
 *
 * @author Maciek Dulkiewicz && Wytse Visser
 */
public class ImplementCategoryChildFactory extends MachineCategoryChildFactory {

    public static final String IMPLEMENT_EXT = "imt";
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.fleet.implement");

    public ImplementCategoryChildFactory(FileObject implementDir) {
        super(IMPLEMENT_EXT, implementDir);
    }

    @Override
    protected Node createNodeForKey(FileObject fileObject) {
        try {
            return new ImplementNode(getNodeFromDataObject(fileObject));
        } catch (DataObjectNotFoundException | NullPointerException ex) {
            LOGGER.log(Level.WARNING, "Could not find fileObject for implement", ex.getMessage());
            return new AbstractNode(Children.LEAF);
        }
    }
}