/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.implement.tree;

import java.io.IOException;
import java.util.ArrayList;
import java.util.List;
import java.util.logging.Level;
import java.util.logging.Logger;
import nl.cloudfarming.client.fleet.machine.tree.MachineCategoryChildFactory;
import org.netbeans.api.project.Project;
import org.netbeans.spi.project.ui.support.NodeFactory;
import org.netbeans.spi.project.ui.support.NodeFactorySupport;
import org.netbeans.spi.project.ui.support.NodeList;
import org.openide.filesystems.FileObject;
import org.openide.nodes.Node;

/**
 *
 * @author Maciek Dulkiewicz& Wytse Visser
 */
@NodeFactory.Registration(projectType = "nl-cloudfarming-client-fleet")
public class ImplementCategoryNodeFactory implements NodeFactory {

    private static final String DIR_NAME = "Implements";
    private static final Logger LOGGER = Logger.getLogger("nl.cloudfarming.client.fleet.implement");

    @Override
    public NodeList<?> createNodes(Project project) {
        List<Node> nodes = new ArrayList<>();

        try {
            createDirectoryIfNotExists(project);
            MachineCategoryChildFactory childFactory = new ImplementCategoryChildFactory(getImplementDirectory(project));
            nodes.add(new ImplementCategoryNode(project, childFactory));
        } catch (IOException ex) {
            LOGGER.log(Level.SEVERE, "Could not create subdirectory for implements", ex.getMessage());
        } finally {
            return NodeFactorySupport.fixedNodeList(nodes.toArray(new Node[nodes.size()]));
        }
    }

    private void createDirectoryIfNotExists(Project project) throws IOException {
        FileObject fleetProjectDir = project.getProjectDirectory();

        if (fleetProjectDir.getFileObject(DIR_NAME) == null) {
            fleetProjectDir.createFolder(DIR_NAME);
        }
    }

    public static FileObject getImplementDirectory(Project project) {
        return project.getProjectDirectory().getFileObject(DIR_NAME);
    }

    public static String getDirectoryName() {
        return DIR_NAME;
    }
}
