/**
 * Copyright (C) 2011 Agrosense <info@cloudfarming.nl>
 *
 * Licensed under the Eclipse Public License - v 1.0 (the "License"); you may
 * not use this file except in compliance with the License. You may obtain a
 * copy of the License at
 *
 * http://www.eclipse.org/legal/epl-v10.html
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 * WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 * License for the specific language governing permissions and limitations under
 * the License.
 */
package nl.cloudfarming.client.fleet.implement.wizard;

import java.awt.Component;
import javax.swing.ImageIcon;
import javax.swing.event.ChangeListener;
import nl.cloudfarming.client.fleet.model.ImplementService;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.api.project.Project;
import org.openide.WizardDescriptor;
import org.openide.WizardValidationException;
import org.openide.util.*;

@NbBundle.Messages({"invalidNameError=Invalid Name", "duplicateNameError=Name already exists"})
public class ImplementWizardPanel1 implements WizardDescriptor.ValidatingPanel<WizardDescriptor> {

    /**
     * The visual component that displays this panel. If you need to access the
     * component from this class, just use getComponent().
     */
    private ImplementVisualPanel1 bodyPanel;
    private ASBodyPanel component;
    private ImageIcon icon = ImageUtilities.loadImageIcon("nl/cloudfarming/client/fleet/implement/implement32.png", true);
    private Project project;
    
    public ImplementWizardPanel1(Project project) {
        this.project = project;
    }

    // Get the visual component for the panel. In this template, the component
    // is kept separate. This can be more efficient: if the wizard is created
    // but never displayed, or not all panels are displayed, it is better to
    // create only those which really need to be visible.
    @Override
    public Component getComponent() {
        if (bodyPanel == null) {
            bodyPanel = new ImplementVisualPanel1();
            component = new ASBodyPanel(bodyPanel);
            component.setName(Bundle.name());
            component.setIcon(icon);
        }
        return component;
    }

    @Override
    public HelpCtx getHelp() {
        // Show no Help button for this panel:
        return HelpCtx.DEFAULT_HELP;
        // If you have context help:
        // return new HelpCtx("help.key.here");
    }

    @Override
    public boolean isValid() {
        return true;
    }

    @Override
    public void addChangeListener(ChangeListener l) {
    }

    @Override
    public void removeChangeListener(ChangeListener l) {
    }

    @Override
    public void readSettings(WizardDescriptor wiz) {
        bodyPanel.getNameField().setText(NbPreferences.forModule(getClass()).get("namePreference", ""));
    }

    @Override
    public void storeSettings(WizardDescriptor wiz) {
        wiz.putProperty("name", bodyPanel.getNameField().getText());
    }

    @Override
    public void validate() throws WizardValidationException {
        String name = bodyPanel.getNameField().getText();
        if(name.equals("")) {
            throw new WizardValidationException(null, Bundle.invalidNameError(), null);
        } else if(implementExists(name)) {
            throw new WizardValidationException(null, Bundle.duplicateNameError(), null);
        }
    }
    
    private boolean implementExists(String name) {
        ImplementService service = Lookup.getDefault().lookup(ImplementService.class);
        return service.getMachine(project, name) != null;
    }
}
